<!--
meta-content-type: text/html; charset=utf-8
meta-viewport: width=device-width, initial-scale=1
title: Example Domains
-->

[![Homepage](/_img/2025.01/iana-logo-header.svg)](/)

* [Domains](/domains)
* [Protocols](/protocols)
* [Numbers](/numbers)
* [About](/about)

Example Domains
===============

As described in [RFC 2606](/go/rfc2606) and [RFC 6761](/go/rfc6761), a
number of domains such as example.com and example.org are maintained
for documentation purposes. These domains may be used as illustrative
examples in documents without prior coordination with us. They are not
available for registration or transfer.

We provide a web service on the example domain hosts to provide basic
information on the purpose of the domain. These web services are
provided as best effort, but are not designed to support production
applications. While incidental traffic for incorrectly configured
applications is expected, please do not design applications that require
the example domains to have operating HTTP service.

Further Reading
---------------

* [IANA\-managed Reserved Domains](/domains/reserved)

Last revised 2017\-05\-13\.

| [Domain Names](/domains) | * [Root Zone Registry](/domains/root) * [.INT Registry](/domains/int) * [.ARPA Registry](/domains/arpa) * [IDN Repository](/domains/idn-tables) |
| --- | --- |
| [Number Resources](/numbers) | * [Abuse Information](/abuse) |
| [Protocols](/protocols) | * [Protocol Registries](/protocols) * [Time Zone Database](/time-zones) |
| [About Us](/about) | * [News](/news) * [Performance](/performance) * [Excellence](/about/excellence) * [Archive](/archive) * [Contact Us](/contact) |

The IANA functions coordinate the Internet’s globally unique identifiers, and
 are provided by [Public Technical Identifiers](https://pti.icann.org), an affiliate of [ICANN](http://www.icann.org/).

* [Privacy Policy](https://www.icann.org/privacy/policy)
* [Terms of Service](https://www.icann.org/privacy/tos)

